"use client";

import Link from "next/link";
import * as echarts from "echarts";
import { useEffect, useRef } from "react";
export default function IncomeQuerry({ children }) {
  var databoard = useRef();
  var incomeOrgin = useRef();
  useEffect(() => {
    createDataBoard();
    createIncomeOrgin();
  }, []);

  const createDataBoard = () => {
    if (databoard.current) {
      var myChart = echarts.init(databoard.current, "dark");
      var option;
      option = {
        backgroundColor: {
          type: "radial",
          x: 0.3,
          y: 0.3,
          r: 0.8,
          colorStops: [
            {
              offset: 0,
              color: "#ffffff00",
            },
            {
              offset: 1,
              color: "#ffffff00",
            },
          ],
        },
        xAxis: {
          type: "category",
          data: getDateStr(),
        },
        yAxis: {
          splitLine: {
            // show: false,
            lineStyle: {
              type: "dashed",
                color: '#ffffff30'
              // ...
            },
          },
          type: "value",
        },
        grid: {
          top: "8%",
          left: "3%",
          right: "4%",
          bottom: "3%",
          containLabel: true,
        },
        series: [
          {
            data: [150, 230, 224, 218, 135, 147, 260],
            type: "line",
            lineStyle: {
                  color: '#ffffff'
                // ...
              },
              itemStyle: {
                color:"#fff",
                backgroundColor:"#fff"
              }
          },
        ],
      };
      option && myChart.setOption(option);
    }
  };
  const createIncomeOrgin = () => {
    if (incomeOrgin.current) {
      var myChart = echarts.init(incomeOrgin.current, "dark");
      var option;
      option = {
        backgroundColor: {
          type: "radial",
          x: 0.3,
          y: 0.3,
          r: 0.8,
          colorStops: [
            {
              offset: 0,
              color: "#ffffff00",
            },
            {
              offset: 1,
              color: "#ffffff00",
            },
          ],
        },
        tooltip: {
          trigger: "item",
        },
        legend: {
          type: "scroll",
          orient: "vertical",
          right: 10,
          top: 20,
          bottom: 20,
          color: "#fff",
          // data: data.legendData
        },
        series: [
          {
            name: "Access From",
            type: "pie",
            radius: ["40%", "70%"],
            center: ["30%", "50%"],
            avoidLabelOverlap: false,
            padAngle: 5,
            itemStyle: {
              borderRadius: 10,
            },
            label: {
              show: false,
              position: "center",
            },
            emphasis: {
              label: {
                show: true,
                fontSize: 40,
                fontWeight: "bold",
              },
            },
            labelLine: {
              show: false,
            },
            data: [
              { value: 1048, name: "空间解锁" },
              { value: 735, name: "付费贴" },
              { value: 580, name: "超粉解锁" },
              { value: 484, name: "个人微信" },
              { value: 300, name: "其他分成" },
            ],
          },
        ],
      };
      option && myChart.setOption(option);
    }
  };

  const getDateStr = () => {
    const currentDay = new Date();
    return Array(7).fill(null).map((it,index)=>{
        const days = (6-index)
        return (currentDay.getMonth()+1)+"."+(currentDay.getDate()-days)
    })
  }
  return (
    <div className="w-full">
      <div className="rounded-2xl bg-gradient-to-r from-[#FF668B] to-[#FF66F0] text-white p-4 h-max mb-4">
        <div className="mb-4">
          <p className="text-md mb-4">可提现钻石</p>
          <div className="flex justify-between items-center">
            <span className="text-3xl font-bold">{39900}</span>
            <Link href={"#"} className="text-sm text-[#7d304c]">
              <span>前往提现</span>
            </Link>
          </div>
        </div>
        <div className="flex justify-between items-center">
          <div className="text-center">
            <p className="text-sm">今日收益</p>
            <p className="text-lg font-bold">{9900}</p>
          </div>
          <div className="text-center">
            <p className="text-sm">待结算</p>
            <p className="text-lg font-bold">{1500}</p>
          </div>
          <div className="text-center">
            <p className="text-sm">近一周收益</p>
            <p className="text-lg font-bold">{15200}</p>
          </div>
        </div>
      </div>
      <div className="rounded-2xl bg-gradient-to-b from-[#ff668c80] to-[#FF668B30] text-white mb-4 p-4">
        <p className="text-md mb-4">数据看板</p>
        <div className="h-40" ref={databoard}></div>
      </div>
      <div className="rounded-2xl bg-gradient-to-b from-[#ff668c80] to-[#FF668B30] text-white mb-4 p-4">
        <p className="text-md mb-4">收益来源</p>
        <div className="h-40" ref={incomeOrgin}></div>
      </div>
    </div>
  );
}
